@@ -10,25 +10,20 @@ try:
 except ImportError:
 
     class FilterBase(QueryAdapter):
-
         # noinspection PyPep8Naming
-        def __init__(
-                self,
-                or_: List['Filter'] = None,
-                and_: List['Filter'] = None
-        ):
+        def __init__(self, or_: List["Filter"] = None, and_: List["Filter"] = None):
             self.or_ = or_
             self.and_ = and_
+
 else:
 
     @dataclass
     class FilterBase(QueryAdapter):
-        and_: List['Filter'] = None
-        or_: List['Filter'] = None
+        and_: List["Filter"] = None
+        or_: List["Filter"] = None
 
 
 class Filter(FilterBase):
-
     def apply(self, query, entities=None):
         return query.filter(*self.criterion(entities=entities))
 
@@ -43,18 +38,19 @@ class Filter(FilterBase):
 
         if self.or_:
             criterion = [
-                or_(*[
-                    and_(*filter.criterion(entities=entities))
-                    for filter in self.or_
-                ])
+                or_(
+                    *[and_(*filter.criterion(entities=entities)) for filter in self.or_]
+                )
             ]
 
         if self.and_:
             criterion = [
-                and_(*[
-                    and_(*filter.criterion(entities=entities))
-                    for filter in self.and_
-                ])
+                and_(
+                    *[
+                        and_(*filter.criterion(entities=entities))
+                        for filter in self.and_
+                    ]
+                )
             ]
 
         return criterion
