@@ -2,21 +2,15 @@ from sqlalchemy.orm import Query as SQLAlchemyQuery
 
 
 class QueryAdapter:
-
     def apply(self, query, entities=None):
         return query
 
 
 class Query(SQLAlchemyQuery):
-
     def _apply_adapters(self, *criterion):
         query = self
-        criterion = [
-            criteria
-            for criteria in criterion
-            if criteria is not None
-        ]
-        entities = [cd['type'] for cd in self.column_descriptions]
+        criterion = [criteria for criteria in criterion if criteria is not None]
+        entities = [cd["type"] for cd in self.column_descriptions]
         for criteria in [*criterion]:
             if isinstance(criteria, QueryAdapter):
                 criterion.remove(criteria)
